@@ -1,6 +1,7 @@
 #[cfg(feature = "engine")]
 pub mod binder;
 #[cfg(feature = "engine")]
-pub use binder::{Binded, Binder};
+pub use binder::BindedTracer;
 
+pub mod description;
 pub mod descriptions_list;
